<?php # $Id: serendipity_lang_tw.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translated by CapriSkye <admin@capriskye.com>
# 				http://open.38.com
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'big5');
@define('SQL_CHARSET', 'big5');
@define('DATE_LOCALES', 'tw, zh, zh-TW, zh_TW');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');
$i18n_unknown = 'tw';

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity ޲z');
@define('HAVE_TO_BE_LOGGED_ON', 'ХnJ');
@define('WRONG_USERNAME_OR_PASSWORD', 'zJF~bαKX');
@define('APPEARANCE', '~[tm');
@define('MANAGE_STYLES', 'G޲z');
@define('CONFIGURE_PLUGINS', ']w~');
@define('CONFIGURATION', '޲z]w');
@define('BACK_TO_BLOG', '^O');
@define('LOGIN', 'nJ');
@define('LOGOUT', 'nX');
@define('LOGGEDOUT', 'nX.');
@define('CREATE', 'إ');
@define('SAVE', 'xs');
@define('NAME', 'W');
@define('CREATE_NEW_CAT', 'sWO');
@define('I_WANT_THUMB', 'ڭnb峹ϥY.');
@define('I_WANT_BIG_IMAGE', 'ڭnb峹ϥΤjϤ.');
@define('I_WANT_NO_LINK', ' ڭnHϤ');
@define('I_WANT_IT_TO_LINK', 'ڭnHsܳo URL:');
@define('BACK', 'h');
@define('FORWARD', 'ei');
@define('ANONYMOUS', 'ΦW');
@define('NEW_TRACKBACK_TO', 'sޥΨ');
@define('NEW_COMMENT_TO', 'sjT');
@define('RECENT', 'sw...');
@define('OLDER', '¤w...');
@define('DONE', '');
@define('WELCOME_BACK', 'w^,');
@define('TITLE', 'D');
@define('DESCRIPTION', '²');
@define('PLACEMENT', '}');
@define('DELETE', 'R');
@define('SAVE', 'xs');
@define('UP', 'W');
@define('DOWN', 'U');
@define('ENTRIES', '峹');
@define('NEW_ENTRY', 'sW峹');
@define('EDIT_ENTRIES', 's峹');
@define('CATEGORIES', 'O');
@define('WARNING_THIS_BLAHBLAH', "ĵi:\\noӥiݭnɶpGܦhOYϪϤ.");
@define('CREATE_THUMBS', 'Y');
@define('MANAGE_IMAGES', '޲zϤ');
@define('NAME', 'W');
@define('EMAIL', 'Email');
@define('HOMEPAGE', '}');
@define('COMMENT', 'jT');
@define('REMEMBER_INFO', 'O? ');
@define('SUBMIT_COMMENT', 'ǰejT');
@define('NO_ENTRIES_TO_PRINT', 'S峹iH');
@define('COMMENTS', 'jT');
@define('ADD_COMMENT', 'sWjT');
@define('NO_COMMENTS', 'SjT');
@define('POSTED_BY', '@');
@define('ON', '');
@define('A_NEW_COMMENT_BLAHBLAH', 'sjTwozO "%s", boӤ峹̭ "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'zO峹 "%s" wFsޥ.');
@define('NO_CATEGORY', 'SO');
@define('ENTRY_BODY', '峹De');
@define('EXTENDED_BODY', '峹Ƥe');
@define('CATEGORY', 'O');
@define('EDIT', 's');
@define('NO_ENTRIES_BLAHBLAH', '䤣즹d %s 峹' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'zjM %s ܤF %s G:');
@define('IMAGE', 'Ϥ');
@define('ERROR_FILE_NOT_EXISTS', '~: ɮפsb!');
@define('ERROR_FILE_EXISTS', '~: ɮצW٤wQϥ, ЭsJ!');
@define('ERROR_SOMETHING', '~: ~.');
@define('ADDING_IMAGE', 'sWϤ...');
@define('THUMB_CREATED_DONE', 'Yϫإ.<br>.');
@define('ERROR_FILE_EXISTS_ALREADY', '~: ɮפwsb!');
@define('ERROR_UNKNOWN_NOUPLOAD', '~o, ɮ٨SW. ]\Aɮפj󭭨jp. и߰ݱz ISP έקz php.ini .');
@define('GO', '~!');
@define('NEWSIZE', 'sjp: ');
@define('RESIZE_BLAHBLAH', '<b>]jp %s</b><p>');
@define('ORIGINAL_SIZE', '즳jp: <i>%sx%s</i> ');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>bo̱ziHקϤjp. pGznק令ۦPϤ, zuݭnJ@ӼƭȵM TAB -- tη|۰zpҥHKX</p>');
@define('QUICKJUMP_CALENDAR', 'ֳtD');
@define('QUICKSEARCH', 'ֳtjM');
@define('SEARCH_FOR_ENTRY', 'jM峹');
@define('ARCHIVES', 'Osw');
@define('BROWSE_ARCHIVES', 'HsOsw');
@define('TOP_REFERRER', 'Dnӷ');
@define('SHOWS_TOP_SITES', 'ܳszO');
@define('TOP_EXITS', 'DnX');
@define('SHOWS_TOP_EXIT', 'ܱzODnX');
@define('SYNDICATION', '峹PB');
@define('SHOWS_RSS_BLAHBLAH', ' RSS PBs');
@define('ADVERTISES_BLAHBLAH', 'ŶǱzO');
@define('HTML_NUGGET', 'HTML T');
@define('HOLDS_A_BLAHBLAH', ' HTML T찼C');
@define('TITLE_FOR_NUGGET', 'TD');
@define('THE_NUGGET', 'HTML T!');
@define('SYNDICATE_THIS_BLOG', 'PBoӤO');
@define('YOU_CHOSE', 'z %s');
@define('IMAGE_SIZE', 'Ϥjp');
@define('IMAGE_AS_A_LINK', 'JϤ');
@define('POWERED_BY', 'Powered by');
@define('TRACKBACKS', 'ޥ');
@define('TRACKBACK', 'ޥ');
@define('NO_TRACKBACKS', 'Sޥ');
@define('TOPICS_OF', 'DD');
@define('VIEW_FULL', 's');
@define('VIEW_TOPICS', 'sDD');
@define('AT', 'ɶ');
@define('SET_AS_TEMPLATE', 'ϥΧG');
@define('IN', 'oG');
@define('EXCERPT', 'Kn');
@define('TRACKED', 'ޥ');
@define('LINK_TO_ENTRY', 's峹');
@define('LINK_TO_REMOTE_ENTRY', 's컷ݤ峹');
@define('IP_ADDRESS', 'IP }');
@define('USER', '@');
@define('THUMBNAIL_USING_OWN', 'ϥ %s YϤؤo]ϤwgܤpF.');
@define('THUMBNAIL_FAILED_COPY', 'ϥ %s Y, OLkƻs!');
@define('AUTHOR', 'o');
@define('LAST_UPDATED', '̫s');
@define('TRACKBACK_SPECIFIC', 'ޥΦ峹Sw URI (})');
@define('DIRECT_LINK', '峹s');
@define('COMMENT_ADDED', 'zjTw\WJ. ');
@define('COMMENT_ADDED_CLICK', 'I %so̪^%s jT, MI %so%s oӵ.');
@define('COMMENT_NOT_ADDED_CLICK', 'I %so̪^%s jT, MI %so%s oӵ.');
@define('COMMENTS_DISABLE', '\jTog峹');
@define('COMMENTS_ENABLE', '\jTog峹');
@define('COMMENTS_CLOSED', '@̤\jTog峹');
@define('EMPTY_COMMENT', 'zjTST,  %s^%s ');
@define('ENTRIES_FOR', '峹b %s');
@define('DOCUMENT_NOT_FOUND', '䤣즹g %s.');
@define('USERNAME', 'b');
@define('PASSWORD', 'KX');
@define('AUTOMATIC_LOGIN', '۰ʵnJ');
@define('SERENDIPITY_INSTALLATION', 'Serendipity w˵{');
@define('LEFT', '');
@define('RIGHT', 'k');
@define('HIDDEN', '');
@define('REMOVE_TICKED_PLUGINS', 'Ŀ諸~');
@define('SAVE_CHANGES_TO_LAYOUT', 'xs~[tm');
@define('COMMENTS_FROM', 'jTӷ');
@define('ERROR', '~');
@define('ENTRY_SAVED', 'z峹wxs');
@define('DELETE_SURE', 'TwnR #%s ?');
@define('NOT_REALLY', 'F...');
@define('DUMP_IT', 'Ra!');
@define('RIP_ENTRY', 'R.I.P. 峹 #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'O #%s wR. ¤峹wQʨO #%s');
@define('CATEGORY_DELETED', 'O #%s wR.');
@define('INVALID_CATEGORY', 'SѧRO');
@define('CATEGORY_SAVED', 'Owxs');
@define('SELECT_TEMPLATE', 'пܺOG');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'SWJ峹!');
@define('MT_DATA_FILE', 'Movable Type ');
@define('FORCE', 'j');
@define('CREATE_AUTHOR', 'sW@ \'%s\'.');
@define('CREATE_CATEGORY', 'sWO \'%s\'.');
@define('MYSQL_REQUIRED', 'zn MySQL XR\~oӰʧ@.');
@define('COULDNT_CONNECT', 'p MySQL Ʈw: %s.');
@define('COULDNT_SELECT_DB', 'ܸƮw: %s.');
@define('COULDNT_SELECT_USER_INFO', 'ܨϥΪ̪: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'O: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'ܤ峹: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'ܰjT: %s.');
@define('YES', 'O');
@define('NO', '_');
@define('USE_DEFAULT', 'w]');
@define('CHECK_N_SAVE', 'xs');
@define('DIRECTORY_WRITE_ERROR', 'Ūgɮק %s. ˬdv.');
@define('DIRECTORY_CREATE_ERROR', 'ɮק %s sb]Lkإ. Цۤvإ߳oɮק');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; run <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Lk %s 귽ɮ');
@define('FILE_WRITE_ERROR', 'LkŪgɮ %s.');
@define('FILE_CREATE_YOURSELF', 'Цۤvإ߳oɮשˬdv');
@define('COPY_CODE_BELOW', '<br />* нƻsUNXMJ %s z %s ɮק:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Ч www ϥΪ̪ Apache (i.e. nobody).');
@define('BROWSER_RELOAD', ', sszs.');
@define('DIAGNOSTIC_ERROR', 'tΰ@ǿ~:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity ٨Sw˧. Ы <a href="%s">w</a>.');
@define('INCLUDE_ERROR', 'serendipity ~: Lk]A %s - hX.');
@define('DATABASE_ERROR', 'serendipity ~: LksƮw - hX.');
@define('CHECK_DATABASE_EXISTS', 'ˬdƮwO_sb. pGzݨƮwd߿~, Фκޥ...');
@define('CREATE_DATABASE', 'إ߹w]Ʈw]w...');
@define('ATTEMPT_WRITE_FILE', 'Ūg %s ɮ...');
@define('SERENDIPITY_INSTALLED', '%sSerendipity ww˧.%s аOozKX: "%s", zbO "%s".%sz{biHsإߪ <a href="%s">O</a>');
@define('WRITTEN_N_SAVED', 'xs');
@define('IMAGE_ALIGNMENT', 'Ϥ');
@define('ENTER_NEW_NAME', 'JsWٵ: ');
@define('RESIZING', ']jp');
@define('RESIZE_DONE', ' (] %s ӹϤ).');
@define('SYNCING', 'iƮwMϤɮקPB');
@define('SYNC_DONE', ' (PBF %s ӹϤ).');
@define('FILE_NOT_FOUND', '䤣ɮצW <b>%s</b>, ]\wgQRF?');
@define('ABORT_NOW', '');
@define('REMOTE_FILE_NOT_FOUND', 'ɮפbݥD, zTwo URL: <b>%s</b> OT?');
@define('FILE_FETCHED', '%s ^ %s');
@define('FILE_UPLOADED', 'ɮ %s WǬ %s');
@define('WORD_OR', '');
@define('SCALING_IMAGE', 'Y %s  %s x %s px');
@define('KEEP_PROPORTIONS', '');
@define('REALLY_SCALE_IMAGE', 'TwnYϤ? oӰʧ@_!');
@define('TOGGLE_ALL', 'i}');
@define('TOGGLE_OPTION', 'ﶵ');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'q\og峹');
@define('UNSUBSCRIBE_OK', "%s wq\og峹");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'sjTq\峹 "%s"');
@define('SUBSCRIPTION_MAIL', "zn %s,\n\nzq\峹FsjTb \"%s\", DO \"%s\"\njTo̬O: %s\n\nziHbo즹峹: %s\n\nziHIoӳsq\: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "zn %s,\n\nzq\峹FsޥΦb \"%s\", DO \"%s\"\nޥΪ@̬O: %s\n\nziHbo즹峹: %s\n\nziHIoӳsq\: %s\n");
@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\nThe best blog around, you can use it too.\nCheck out <http://s9y.org> to find out how.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comments');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', ' "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  ' "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'RSS feed Ϥ');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Ϥe');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Ϥ');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  '޲zqll, pG. (ť: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', '@̪qll, pG. (ť: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'Ϥ} URL, H GIF/JPEG/PNG 榡, pG. (ť: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', ', ̤j. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', ', ̤j. 400');
@define('SYNDICATION_PLUGIN_TTL', ' "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'LXz峹|Q~Ӫε{xs֨Oи (ť: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', ' "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', '"pubDate"-ݭnORSS-WD, H̫ܳ峹?');
@define('CONTENT', 'e');
@define('TYPE', '');
@define('DRAFT', 'Z');
@define('PUBLISH', '}');
@define('PREVIEW', 'w');
@define('DATE', '');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'ĵi: zѪT. O YYYY-MM-DD HH:MM 榡.');
@define('CATEGORY_PLUGIN_DESC', 'OM.');
@define('ALL_AUTHORS', '@');
@define('CATEGORIES_TO_FETCH', 'O');
@define('CATEGORIES_TO_FETCH_DESC', 'ܭ@̪O?');
@define('PAGE_BROWSE_ENTRIES', ' %s @ %s, `@ %s g峹');
@define('PREVIOUS_PAGE', 'W@');
@define('NEXT_PAGE', 'U@');
@define('ALL_CATEGORIES', 'O');
@define('DO_MARKUP', 'аOഫ');
@define('GENERAL_PLUGIN_DATEFORMAT', '榡');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', '峹榡, ϥ PHP  strftime() ܼ. (w]: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Lk}ҧGɮ, Чs serendipity!');
@define('ADVANCED_OPTIONS', 'iﶵ');
@define('EDIT_ENTRY', 's峹');
@define('HTACCESS_ERROR', 'nˬdzDw˳]w, serendipity ݭnŪgɮ ".htaccess". O]v~, Skzˬd. Чɮvo: <br />&nbsp;&nbsp;%s<br />M᭫ssoӺ.');
@define('SIDEBAR_PLUGINS', 'C~');
@define('EVENT_PLUGINS', 'ƥ~');
@define('SORT_ORDER', 'Ƨ');
@define('SORT_ORDER_NAME', 'ɮצW');
@define('SORT_ORDER_EXTENSION', 'ɦW');
@define('SORT_ORDER_SIZE', 'ɮפjp');
@define('SORT_ORDER_WIDTH', 'Ϥe');
@define('SORT_ORDER_HEIGHT', 'Ϥ');
@define('SORT_ORDER_DATE', 'WǤ');
@define('SORT_ORDER_ASC', 'WƧ');
@define('SORT_ORDER_DESC', 'Ƨ');
@define('THUMBNAIL_SHORT', 'Y');
@define('ORIGINAL_SHORT', 'l');
@define('APPLY_MARKUP_TO', 'MμаO %s');
@define('CALENDAR_BEGINNING_OF_WEEK', '@gĤ@');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity ztmO %s, O Serendipity w˪O %s, Чsz{! <a href="%s">s</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'zn, wӨ Serendipity st.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'stη|zs Serendipity  %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'zݨoӰTO]zwˤF Serendipity  %s, OzSsƮw');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Ʈws (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'tΧHU .sql , ɮץ~~w Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Sw');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'SSw');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'TwnWȶ?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'ڦۤv');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'ڰ');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'zݭnis');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', ' Serendipity sa');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'zLFs, нTwƮwww˧, MLȦw˵L~');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'z Serendipity Hsܪ %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'ziHI %so%s ^O');
@define('MANAGE_USERS', '޲z@');
@define('CREATE_NEW_USER', 'sW@');
@define('CREATE_NOT_AUTHORIZED', 'zקzۦPv@');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'zsWzv@');
@define('CREATED_USER', 's@ %s wgsW');
@define('MODIFIED_USER', '@ %s Ƥwg');
@define('USER_LEVEL', '@v');
@define('DELETE_USER', 'znRoӧ@ #%d %s. Tw? o|bDåLҼg峹.');
@define('DELETED_USER', '@ #%d %s wQR.');
@define('LIMIT_TO_NUMBER', 'nܦhֶ?');
@define('ENTRIES_PER_PAGE', 'Cܪ峹');
@define('XML_IMAGE_TO_DISPLAY', 'XML s');
@define('XML_IMAGE_TO_DISPLAY_DESC','s XML Feeds |γoӹϤ. gN|ϥιw]Ϥ, οJ \'none\' oӥ\.');

@define('DIRECTORIES_AVAILABLE', 'ziHblؿIؿӫإ߷sؿ.');
@define('ALL_DIRECTORIES', 'غ');
@define('MANAGE_DIRECTORIES', '޲zؿ');
@define('DIRECTORY_CREATED', 'ؿ <strong>%s</strong> wgsW.');
@define('PARENT_DIRECTORY', 'ؿ');
@define('CONFIRM_DELETE_DIRECTORY', 'TwnRoӥؿe %s?');
@define('ERROR_NO_DIRECTORY', '~: ؿ %s sb');
@define('CHECKING_DIRECTORY', 'ˬdؿɮ %s');
@define('DELETING_FILE', 'Rɮ %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'ಾMŪؿ. Ŀ "jR" ֨pGznoɮ, Mb~. sbɮ׬O:');
@define('DIRECTORY_DELETE_FAILED', 'Rؿ %s. ˬdvάݤWT.');
@define('DIRECTORY_DELETE_SUCCESS', 'ؿ %s \R.');
@define('SKIPPING_FILE_EXTENSION', 'Lɮ: S %s ɦW.');
@define('SKIPPING_FILE_UNREADABLE', 'Lɮ: %s Ū.');
@define('FOUND_FILE', ' s/ק Lɮ: %s.');
@define('ALREADY_SUBCATEGORY', '%s wgOOlO %s.');
@define('PARENT_CATEGORY', 'O');
@define('IN_REPLY_TO', '^Ш');
@define('TOP_LEVEL', '̰h');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'v');
@define('SETTINGS_SAVED_AT', 's]wwgxs %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Ʈw]w');
@define('INSTALL_CAT_DB_DESC', 'ziHboJƮw. Serendipity ݭnoǸƤ~ॿ`B@');
@define('INSTALL_DBTYPE', 'Ʈw');
@define('INSTALL_DBTYPE_DESC', 'Ʈw');
@define('INSTALL_DBHOST', 'ƮwD');
@define('INSTALL_DBHOST_DESC', 'ƮwDW');
@define('INSTALL_DBUSER', 'Ʈwb');
@define('INSTALL_DBUSER_DESC', 'nJƮwb');
@define('INSTALL_DBPASS', 'ƮwKX');
@define('INSTALL_DBPASS_DESC', 'zƮwKX');
@define('INSTALL_DBNAME', 'ƮwW');
@define('INSTALL_DBNAME_DESC', 'ƮwW');
@define('INSTALL_DBPREFIX', 'ƪemW');
@define('INSTALL_DBPREFIX_DESC', 'ƪemW, Ҧp serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', '|]w');
@define('INSTALL_CAT_PATHS_DESC', 'ɮק|. nѤF̫᪺׽u!');
@define('INSTALL_FULLPATH', '|');
@define('INSTALL_FULLPATH_DESC', 'z Serendipity w˪|M|');
@define('INSTALL_UPLOADPATH', 'WǸ|');
@define('INSTALL_UPLOADPATH_DESC', 'Wɮ׷|so, H \'|\' ܪ۹| - Ҧp \'uploads/\'');
@define('INSTALL_RELPATH', '۹|');
@define('INSTALL_RELPATH_DESC', 's|, Ҧp \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', '۹諸G|');
@define('INSTALL_RELTEMPLPATH_DESC', 'zG| - H \'۹|\' ܪ۹|');
@define('INSTALL_RELUPLOADPATH', '۹諸WǸ|');
@define('INSTALL_RELUPLOADPATH_DESC', 'sWɮת| - H \'۹|\' ܪ۹|');
@define('INSTALL_URL', 'O URL');
@define('INSTALL_URL_DESC', 'z Serendipity w˪ URL');
@define('INSTALL_INDEXFILE', 'Index ɮ');
@define('INSTALL_INDEXFILE_DESC', 'Serendipity  index ɮ');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', '@]w');
@define('INSTALL_CAT_SETTINGS_DESC', 'Serendipity @]w');
@define('INSTALL_USERNAME', '޲zb');
@define('INSTALL_USERNAME_DESC', '޲znJW');
@define('INSTALL_PASSWORD', '޲zKX');
@define('INSTALL_PASSWORD_DESC', '޲znJKX');
@define('INSTALL_EMAIL', 'qll');
@define('INSTALL_EMAIL_DESC', '޲zqll');
@define('INSTALL_SENDMAIL', 'Heqll󵹺޲z?');
@define('INSTALL_SENDMAIL_DESC', 'HoGjTz峹ɭnqllq?');
@define('INSTALL_SUBSCRIBE', '\ϥΪ̭q\峹?');
@define('INSTALL_SUBSCRIBE_DESC', 'ziH\ϥΪ̦qllq, jToGɦo̷|q.');
@define('INSTALL_BLOGNAME', 'OW');
@define('INSTALL_BLOGNAME_DESC', 'zOD');
@define('INSTALL_BLOGDESC', 'O²');
@define('INSTALL_BLOGDESC_DESC', 'бzO');
@define('INSTALL_LANG', 'yt');
@define('INSTALL_LANG_DESC', 'zOϥΪyt');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', '~[οﶵ]w');
@define('INSTALL_CAT_DISPLAY_DESC', 'z]w Serendipity ~[ML]w');
@define('INSTALL_WYSIWYG', 'ϥ WYSIWYG s边');
@define('INSTALL_WYSIWYG_DESC', 'znϥ WYSIWYG s边? (ib IE5+ ϥ, YǳiϥΩ Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'jŦX XHTML 1.1 nD');
@define('INSTALL_XHTML11_DESC', 'ziHzOjŦX XHTML 1.1 nD (ªsi| x/ex D)');
@define('INSTALL_POPUP', 'ϥμuX');
@define('INSTALL_POPUP_DESC', 'znbjT, ޥεaϥμuX?');
@define('INSTALL_EMBED', 'ϥΤO\?');
@define('INSTALL_EMBED_DESC', 'pGAnN Serendipity HO覡,  O |z˱DMuܤOe. ziH indexFile ]wӨϥΥ]˨禡OHKzJD. ԱЬd README ɮ!');
@define('INSTALL_TOP_AS_LINKS', 'Hs DnX/Dnӷ?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"_": XMӷNΤrܥHקK google si. "O": XMӷNγs. "w]": Υϸ̭]w (ĳ).');
@define('INSTALL_BLOCKREF', 'רӷ');
@define('INSTALL_BLOCKREF_DESC', 'SDzQbӷܶ?  \';\' Ӥ}DW, `NDOHlr覡!');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'пܱzQΪ URL Rewriting 覡. } rewrite Wh|HM覡 URL, HKjMॿTnJz峹. zD䴩 mod_rewrite  "AllowOverride All" z Serendipity ɮק. w]]wOtΦ۰z');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Ϥഫ]w');
@define('INSTALL_CAT_IMAGECONV_DESC', 'г]w Serendipity ]wϤഫ覡');
@define('INSTALL_IMAGEMAGICK', 'ϥ Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'pGw image magick, znΥӧܹϤjp?');
@define('INSTALL_IMAGEMAGICKPATH', 'ഫ{|');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'image magick ഫ{|MW');
@define('INSTALL_THUMBSUFFIX', 'Yϫmr');
@define('INSTALL_THUMBSUFFIX_DESC', 'YϷ|HU榡sRW: ɦW.[mr].ext');
@define('INSTALL_THUMBWIDTH', 'YϤث');
@define('INSTALL_THUMBWIDTH_DESC', '۰ʫإYϪ̤je');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'ӤHƳ]w');
@define('USERCONF_CAT_PERSONAL_DESC', 'ܱzӤH');
@define('USERCONF_USERNAME', 'zb');
@define('USERCONF_USERNAME_DESC', 'znJxW');
@define('USERCONF_PASSWORD', 'zKX');
@define('USERCONF_PASSWORD_DESC', 'znJxKX');
@define('USERCONF_EMAIL', 'zqll');
@define('USERCONF_EMAIL_DESC', 'zϥΪqll');
@define('USERCONF_SENDCOMMENTS', 'HejTq?');
@define('USERCONF_SENDCOMMENTS_DESC', 'sjTz峹ɭnqz?');
@define('USERCONF_SENDTRACKBACKS', 'Heޥγq?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'sޥΨz峹ɭnqz?');
@define('USERCONF_ALLOWPUBLISH', 'v: ioG峹?');
@define('USERCONF_ALLOWPUBLISH_DESC', '\o@̵oG峹?');
@define('SUCCESS', '');
@define('POWERED_BY_SHOW_TEXT', 'Hr "Serendipity"');
@define('POWERED_BY_SHOW_TEXT_DESC', 'NΤr "Serendipity Weblog"');
@define('POWERED_BY_SHOW_IMAGE', 'H logo  "Serendipity"');
@define('POWERED_BY_SHOW_IMAGE_DESC', ' Serendipity  logo');
@define('PLUGIN_ITEM_DISPLAY', 'Ӷتܦ}?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'ubƤe');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'ub[');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'û');

@define('COMMENTS_WILL_BE_MODERATED', 'oGjTNݭn޲zf.');
@define('YOU_HAVE_THESE_OPTIONS', 'zHU:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'ĵi: oӰjTf֤~|');
@define('DELETE_COMMENT', 'RjT');
@define('APPROVE_COMMENT', '{ijT');
@define('REQUIRES_REVIEW', 'ݭnf');
@define('COMMENT_APPROVED', 'jT #%s wgqLf');
@define('COMMENT_DELETED', 'jT #%s wg\R');
@define('COMMENTS_MODERATE', 'jTMޥΨoӤ峹ݭn޲zf');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'ĵi: oӤޥλݭn޲zf֤~|');
@define('DELETE_TRACKBACK', 'Rޥ');
@define('APPROVE_TRACKBACK', '{iޥ');
@define('TRACKBACK_APPROVED', 'ޥ #%s wgqLf');
@define('TRACKBACK_DELETED', 'ޥ #%s wg\R');
@define('VIEW', 's');
@define('COMMENT_ALREADY_APPROVED', 'jT #%s wgqLf');
@define('COMMENT_EDITED', '峹wQs');
@define('HIDE', '');
@define('VIEW_EXTENDED_ENTRY', '~\Ū "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'oӳsOΨI. ]tFoӤ峹ޥ URI. ziHqzxγo URI Ӷǰe ping MޥΨoӤ峹. pGnƻsoӳs, bsWIkM "ƻss" (IE)  "ƻss}" (Mozilla).');
@define('PLUGIN_SUPERUSER_HTTPS', ' https nJ');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'nJss https }. zD䴩o\!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', '~ӳsHs?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"_": ~ӳs (DnX, Dnӷ, jT) |HrܥHקK google si (ĳϥ). "O": ~ӳsNHWs覡. iHbC~\L]w!');
@define('PAGE_BROWSE_COMMENTS', ' %s @ %s, `@ %s ӰjT');
@define('FILTERS', 'Lo');
@define('FIND_ENTRIES', 'jM峹');
@define('FIND_COMMENTS', 'jMjT');
@define('FIND_MEDIA', 'jMC');
@define('FILTER_DIRECTORY', 'ؿ');
@define('SORT_BY', 'Ƨ');
@define('TRACKBACK_COULD_NOT_CONNECT', 'SeXޥ: Lk}ҽu %s γs %d');
@define('MEDIA', 'C');
@define('MEDIA_LIBRARY', 'Csw');
@define('ADD_MEDIA', 'sWC');
@define('ENTER_MEDIA_URL', 'пJɮת URL:');
@define('ENTER_MEDIA_UPLOAD', 'пܭnWǪɮ:');
@define('SAVE_FILE_AS', 'xsɮ:');
@define('STORE_IN_DIRECTORY', 'xsHUؿ: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>sWɮרCsw:</b><p>ziHboWǴC, ΧiDtΨM! pGzSQnϤ, ziH <a href="http://images.google.com" target="_blank">googleMϤ</a>.</p><p><b>ܤ覡:</b></p><br/>');
@define('MEDIA_RENAME', 'ɮצW');
@define('IMAGE_RESIZE', 'Ϥؤo');
@define('MEDIA_DELETE', 'Roɮ');
@define('FILES_PER_PAGE', 'Cܪɮ׼');
@define('CLICK_FILE_TO_INSERT', 'IznJɮ:');
@define('SELECT_FILE', 'ܭnJɮ');
@define('MEDIA_FULLSIZE', 'ؤo');
@define('CALENDAR_BOW_DESC', '@§Ĥ@. w]OP@');
@define('SUPERUSER', 'x޲z');
@define('ALLOWS_YOU_BLAHBLAH', 'bCѳsx޲z');
@define('CALENDAR', '');
@define('SUPERUSER_OPEN_ADMIN', '}Һ޲z');
@define('SUPERUSER_OPEN_LOGIN', '}ҵnJ');
@define('INVERT_SELECTIONS', 'AˤĿ');
@define('COMMENTS_DELETE_CONFIRM', 'TwnRĿ諸jT?');
@define('COMMENT_DELETE_CONFIRM', 'TwnRjT #%d, oG̬O %s?');
@define('DELETE_SELECTED_COMMENTS', 'RĿ諸jT');
@define('VIEW_COMMENT', 'sjT');
@define('VIEW_ENTRY', 's峹');
@define('DELETE_FILE_FAIL' , 'LkRɮ <b>%s</b>');
@define('DELETE_THUMBNAIL', 'RFϤY <b>%s</b>');
@define('DELETE_FILE', 'RFɮ <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'zNRɮ <b>%s</b><br />pGzbL峹ϥγoɮ, ӳsιϤN|L<br />Twn~?<br /><br />');
@define('TRACKBACK_SENDING', 'ǰeޥΨ URI %s...');
@define('TRACKBACK_SENT', 'ޥΧ');
@define('TRACKBACK_FAILED', 'ޥο~: %s');
@define('TRACKBACK_NOT_FOUND', '䤣ޥΪURI.');
@define('TRACKBACK_URI_MISMATCH', '۰ʷjMޥθޥΥؼФۦP.');
@define('TRACKBACK_CHECKING', 'jM <u>%s</u> ޥ...');
@define('TRACKBACK_NO_DATA', 'ؼШS');
@define('TRACKBACK_SIZE', 'ؼ URI WXF\ %s bytes ɮפjp.');
@define('COMMENTS_VIEWMODE_THREADED', 'u{');
@define('COMMENTS_VIEWMODE_LINEAR', 'u{');
@define('DISPLAY_COMMENTS_AS', 'jTܤ覡');
@define('COMMENTS_FILTER_SHOW', '');
@define('COMMENTS_FILTER_ALL', '');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'ܼfְjT');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'ܵݼf');
@define('RSS_IMPORT_BODYONLY', 'NJrDe, N}L峹Ƥea.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'b RSS feed ܥ峹');
@define('WEEK', 'g');
@define('WEEKS', 'g');
@define('MONTHS', '');
@define('DAYS', '');
@define('ARCHIVE_FREQUENCY', 'OswWv');
@define('ARCHIVE_FREQUENCY_DESC', 'OswϥΪزM涡j');
@define('ARCHIVE_COUNT', 'Oswؼ');
@define('ARCHIVE_COUNT_DESC', 'ܪ, g, Τ');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'UOw˦n~');
@define('SIDEBAR_PLUGIN', 'C~');
@define('EVENT_PLUGIN', 'ƥ~');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Io̦w˷s %s');
@define('VERSION', '');
@define('INSTALL', 'w');
@define('ALREADY_INSTALLED', 'wgw');
@define('SELECT_A_PLUGIN_TO_ADD', 'пܭnw˪~');
@define('RSS_IMPORT_CATEGORY', 'γoOۦPJ峹');

@define('INSTALL_OFFSET', 'Dɰ');
@define('STICKY_POSTINGS', 'm峹');
@define('INSTALL_FETCHLIMIT', 'bDܪ峹');
@define('INSTALL_FETCHLIMIT_DESC', 'Dܪ峹');
@define('IMPORT_ENTRIES', 'J');
@define('EXPORT_ENTRIES', 'X');
@define('IMPORT_WELCOME', 'wӨ Serendipity Ju');
@define('IMPORT_WHAT_CAN', 'bo̱ziHJbLx{̪峹');
@define('IMPORT_SELECT', 'пܿJ峹x{');
@define('IMPORT_PLEASE_ENTER', 'пJ');
@define('IMPORT_NOW', '}lJ!');
@define('IMPORT_STARTING', '}lJ{...');
@define('IMPORT_FAILED', 'J');
@define('IMPORT_DONE', 'J');
@define('IMPORT_WEBLOG_APP', 'x{');
@define('EXPORT_FEED', 'X㪺 RSS');
@define('STATUS', 'J᪺A');
@define('IMPORT_GENERIC_RSS', '@ RSS J');
@define('ACTIVATE_AUTODISCOVERY', 'ǰeb峹쪺ޥγs');
@define('WELCOME_TO_ADMIN', 'w Serendipity ޲z.');
@define('PLEASE_ENTER_CREDENTIALS', 'пJz.');
@define('ADMIN_FOOTER_POWERED_BY', 'Powered by Serendipity %s and PHP %s');
@define('INSTALL_USEGZIP', 'ϥ gzip Y');
@define('INSTALL_USEGZIP_DESC', 'Fֳt, ڭ̷|NYMܳX, pGXȨϥΪs䴩Y. ĳϥ');
@define('INSTALL_SHOWFUTURE', 'ܥӤ峹');
@define('INSTALL_SHOWFUTURE_DESC', 'pG}, zxN|ܩҦӤ峹. w]]wONӤ峹, MoGɦ۰.');
@define('INSTALL_DBPERSISTENT', 'ϥΫsu');
@define('INSTALL_DBPERSISTENT_DESC', 'ƮwϥΫsu, ԱШ <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">o</a>. q`äĳϥ');
@define('NO_IMAGES_FOUND', '䤣Ϥ');
@define('PERSONAL_SETTINGS', 'ӤH]w');
@define('REFERER', 'ӷ');
@define('NOT_FOUND', '䤣');
@define('NOT_WRITABLE', 'iŪg');
@define('WRITABLE', 'iŪg');
@define('PROBLEM_DIAGNOSTIC', ']WX{D, zN~ѨM~~w');
@define('SELECT_INSTALLATION_TYPE', 'пܦw');
@define('WELCOME_TO_INSTALLATION', 'w Serendipity w˵{');
@define('FIRST_WE_TAKE_A_LOOK', 'w˵{|ˬdzD]wHקKX{~');
@define('ERRORS_ARE_DISPLAYED_IN', '~ %s, ĳ %s L~ %s');
@define('RED', '');
@define('YELLOW', '');
@define('GREEN', '');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s w˫ei');
@define('RECOMMENDED', 'ĳ');
@define('ACTUAL', '');
@define('PHPINI_CONFIGURATION', 'php.ini ]w');
@define('PHP_INSTALLATION', 'PHP w');
@define('THEY_DO', 'they do'); // translate
@define('THEY_DONT', 'they don\'t'); // Translate
@define('SIMPLE_INSTALLATION', 'ֳtw');
@define('EXPERT_INSTALLATION', 'iw');
@define('COMPLETE_INSTALLATION', 'w');
@define('WONT_INSTALL_DB_AGAIN', '|sw˸Ʈw');
@define('CHECK_DATABASE_EXISTS', 'ˬdO_ƮwMƪwgsb');
@define('CREATING_PRIMARY_AUTHOR', 'إߥDn@ \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', ']ww]G');
@define('INSTALLING_DEFAULT_PLUGINS', 'w˹w]~');
@define('SERENDIPITY_INSTALLED', 'Serendipity ww');
@define('VISIT_BLOG_HERE', '[zx');
@define('THANK_YOU_FOR_CHOOSING', 'P±z Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'wˮɵoͿ~');
@define('OPERATING_SYSTEM', '@~t');
@define('WEBSERVER_SAPI', 'D SAPI');
@define('TEMPLATE_SET', '\'%s\' wQ]wzDnG');
@define('SEARCH_ERROR', 'jM\oͿ~. i޲z: oͳoӿ~i]ƮwST index keys. pGϥ MySQL, zbi: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> v. Ʈwܪ~O: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 's "%s"');
@define('CATEGORY_REMAINING', 'RoOMṊ峹oO');
@define('CATEGORY_INDEX', 'UOiʨ쪺O');
@define('NO_CATEGORIES', 'SO');
@define('RESET_DATE', ']');
@define('RESET_DATE_DESC', 'Io̭]');
@define('PROBLEM_PERMISSIONS_HOWTO', 'viHΤU Shell ROӰ: `<em>%s</em>` MbnvɮקAΥ FTP n');
@define('WARNING_TEMPLATE_DEPRECATED', 'ĵi: zثeϥΪGOªks@Aкɧ֧s');
@define('ENTRY_PUBLISHED_FUTURE', 'og峹٥}C');
@define('ENTRIES_BY', '@ %s');
@define('PREVIOUS', 'W@');
@define('NEXT', 'U@');
@define('APPROVE', '{i');
@define('DO_MARKUP_DESCRIPTION', 'MΦ۰ʮ榡ƨ峹 (Ϯ, Ÿ *, /, _, ...)Co\N|Os峹X{ HTML XC');
@define('CATEGORY_ALREADY_EXIST', 'O "%s" wgsb');
@define('IMPORT_NOTES', '`N:');
@define('ERROR_FILE_FORBIDDEN', 'zWǦɮ');
@define('ADMIN', '޲z');
@define('ADMIN_FRONTPAGE', '޲z');
@define('QUOTE', 'ި');
@define('IFRAME_SAVE', 'Serendipity bxsz峹AإߤޥΩM XML-RPC callsAеy..');
@define('IFRAME_SAVE_DRAFT', '峹ZwQxs');
@define('IFRAME_PREVIEW', 'Serendipity bإ߱zw峹...');
@define('IFRAME_WARNING', 'zs䴩 iframes. Х} serendipity_config.inc.php ɮ׵M]w $serendipity[\'use_iframe\'] ܼƦ FALSE.');
@define('NONE', 'S');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 's峹Nϥιw]]w');
@define('UPGRADE', 's');
@define('UPGRADE_TO_VERSION', 'sܪ %s');
@define('DELETE_DIRECTORY', 'Rؿ');
@define('DELETE_DIRECTORY_DESC', 'zNRؿCɮסA`Nɮפ]\X{bL峹C');
@define('FORCE_DELETE', 'RؿɮסA]A Serendipity LkѧOɮ');
@define('CREATE_DIRECTORY', 'إߥؿ');
@define('CREATE_NEW_DIRECTORY', 'إ߷sؿ');
@define('CREATE_DIRECTORY_DESC', 'bo̱ziHإ߷sؿӦsCɮסCJؿWٵMziHܬO_NؿC');
@define('BASE_DIRECTORY', '򥻥ؿ');
@define('USERLEVEL_EDITOR_DESC', '@@');
@define('USERLEVEL_CHIEF_DESC', 'Ds');
@define('USERLEVEL_ADMIN_DESC', '޲z');
@define('USERCONF_USERLEVEL', 'v');
@define('USERCONF_USERLEVEL_DESC', 'oӿﶵiH]w@̦boӺxv');
@define('USER_SELF_INFO', 'nJ@̬O %s (%s)');
@define('ADMIN_ENTRIES', '峹');
@define('RECHECK_INSTALLATION', 'sˬdw˵{');
@define('IMAGICK_EXEC_ERROR', 'Lk: "%s", ~: %s, Ǧ^ܼ: %d');
@define('INSTALL_OFFSET_DESC', 'HpɭpAпJDɶ (ثe: %clock%) zɰϪɮt');
@define('UNMET_REQUIREMENTS', 'FݨD: %s');
@define('CHARSET', 'sX');
@define('AUTOLANG', 'ϥŪ̪s]wyt');
@define('AUTOLANG_DESC', 'pG}ҡAoӥ\NϥŪ̪sҳ]wytC');
@define('INSTALL_AUTODETECT_URL', '۰ʰ HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'pG]w "true"ASerendipity |TwŪ̪ HTTP Host z URL ]wۦPC}ҳo\iH\zϥΦhƪWٵzxAMϥγoӺ쵹isC');
@define('CONVERT_HTMLENTITIES', '۰ʧ HTML ?');
@define('EMPTY_SETTING', 'zS "%s" T!');
@define('USERCONF_REALNAME', 'W');
@define('USERCONF_REALNAME_DESC', '@̪WANܵŪ');
@define('HOTLINK_DONE', 'ɮץ~s<br />C');
@define('ENTER_MEDIA_URL_METHOD', 'ok:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', '`N: pGzܥ~skAХoӷ\C~s\zΨLϤӤݱNϤxsbzDC');
@define('MEDIA_HOTLINKED', '~sϤ');
@define('FETCH_METHOD_IMAGE', 'UϤD');
@define('FETCH_METHOD_HOTLINK', '~sD');
@define('DELETE_HOTLINK_FILE', 'R~sɮ <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'ܹqll?');
@define('IMAGE_MORE_INPUT', 'sWϤ');
@define('BACKEND_TITLE', '~tmB~T');
@define('BACKEND_TITLE_FOR_NUGGET', 'o̱ziH]w@ǦۭqrA̸ HTML Nugget ~@˷|ܦb~tmCpGzhӨSD HTML NuggetsAoӥiHzhۦP~C');
@define('CATEGORIES_ALLOW_SELECT', '\XܦhƪOH');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'pG}ҳoӿﶵAb sidebar ~̪O|X{ĿC|iHĿnܪOC');
@define('PAGE_BROWSE_PLUGINS', ' %s @ %s, `@ %s ӥ~C');
@define('INSTALL_CAT_PERMALINKS', 'RAs');
@define('INSTALL_CAT_PERMALINKS_DESC', 'QΦUؤP URL ˦өwqxRAsCĳzιw]˦AΪ̥ %id% ȨקK s9y QθƮwM URL ؼСC');
@define('INSTALL_PERMALINK', '峹RAs');
@define('INSTALL_PERMALINK_DESC', 'o̥iHz]wH򩳦}ӭp峹۹sCziHΥHUܼơG%id%, %title%, %day%, %month%, %year% ΨLrC');
@define('INSTALL_PERMALINK_AUTHOR', '@̪RAs');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'o̥iHz]wH򩳦}ӭp@̤峹۹sCziHΥHUܼơG%id%, %realname%, %username%, %email% ΨLrC');
@define('INSTALL_PERMALINK_CATEGORY', 'ORAs');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'o̥iHz]wH򩳦}ӭpO峹۹sCziHΥHUܼơG%id%, %name%, %description% ΨLrC');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-Feed ORAs');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'o̥iHz]wH򩳦}ӭp RSS-Feed O峹۹sCziHΥHUܼơG%id%, %name%, %description% ΨLrC');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Osw|');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Osw|');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'O|');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'ϭq\jT|');
@define('INSTALL_PERMALINK_DELETEPATH', 'RjT|');
@define('INSTALL_PERMALINK_APPROVEPATH', '֭jT|');
@define('INSTALL_PERMALINK_FEEDSPATH', 'RSS Feeds |');
@define('INSTALL_PERMALINK_PLUGINPATH', '~|');
@define('INSTALL_PERMALINK_ADMINPATH', '޲z|');
@define('INSTALL_PERMALINK_SEARCHPATH', 'jM|');
@define('INSTALL_CAL', '');
@define('INSTALL_CAL_DESC', 'пܱzn');
@define('REPLY', '^');
@define('USERCONF_GROUPS', '|s');
@define('USERCONF_GROUPS_DESC', '|OUsղխC|iH[JhӸsաC');
@define('MANAGE_GROUPS', '޲zs');
@define('DELETED_GROUP', 's #%d %s wRC');
@define('CREATED_GROUP', 'ss %s wsW');
@define('MODIFIED_GROUP', 's %s ]wwQ');
@define('GROUP', 's');
@define('CREATE_NEW_GROUP', 'sWs');
@define('DELETE_GROUP', 'TwnRs #%d %s ܡH');
@define('USERLEVEL_OBSOLETE', '`N: |vݩʥuF^ۮeʩM~vCtβ{bϥΤFs|vӺ޲zvC');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'znoG峹 ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner Ϥ');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', ' feedburner.com ϤܪW (Ϊťեέpƾ)CҦpGfbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner D');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'ܩϤǪD (pG)');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner Ϥr');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'ƹWϤܪr (pG)');
@define('SEARCH_TOO_SHORT', 'zjMrh 3 ӦrCziH * ӥNUΦrApGjMrp 3 ӦrCҦpGs9y*C');
@define('INSTALL_DBPORT', 'Ʈws');
@define('INSTALL_DBPORT_DESC', 'sƮwҨϥΪs');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'eݡG~A');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'eݡG\');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'eݡG~');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'eݡGs');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'eݡG峹');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'ݡGs边');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'ݡG|޲z');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'ݡGMeta T');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'ݡGҪO');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'ݡG\');
@define('PLUGIN_GROUP_IMAGES', 'Ϥ');
@define('PLUGIN_GROUP_ANTISPAM', 'si');
@define('PLUGIN_GROUP_MARKUP', 'аO');
@define('PLUGIN_GROUP_STATISTICS', 'έp');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: ŪpH]w');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: ܷ|v');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate:  "Tإߤ峹"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: ܵoG峹v');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Ūtγ]w');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Ūx]w');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: ޲z峹');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: ޲z|峹');
@define('PERMISSION_ADMINIMPORT', 'adminImport: J峹');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: ޲zO');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: ޲z|O');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: RO');
@define('PERMISSION_ADMINUSERS', 'adminUsers: ޲z|');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: R|');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: v');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: ޲zۦPsժ|');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: ޲z䥦sժ|');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: sW|');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: ޲zs');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: ޲z~');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: ޲z|~');
@define('PERMISSION_ADMINIMAGES', 'adminImages: ޲zCɮ');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: ޲zCؿ');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: sWCɮ');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: RCɮ');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: ޲z|Cɮ');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: sCɮ');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: PBY');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: ޲zjT');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: ޲zG');
@define('INSTALL_BLOG_EMAIL', 'xqll');
@define('INSTALL_BLOG_EMAIL_DESC', 'o|]wzqllAqxHXHN|ܳoӶl}COooӹqll󥲶iHΦbzDAܦhD|ڵlC');
@define('CATEGORIES_PARENT_BASE', 'uܤUO...');
@define('CATEGORIES_PARENT_BASE_DESC', 'ziHܤ@ӥOAuܥUlOC');
@define('CATEGORIES_HIDE_PARALLEL', 'äbOcO');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'pGnæ䥦OcOAz}ҳoӳ]wCoӥ\q`OΦbhx~C');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: s|Cɮ');
@define('CHARSET_NATIVE', 'w]');
@define('INSTALL_CHARSET', 'ytﶵ');
@define('INSTALL_CHARSET_DESC', 'o̥iHzഫ UTF-8 ιw]yt (ISO, EUC, ...)Cǻyu UTF-8 ytɡAҥHw]yt|ܥFCsw˪xĳϥ UTF-8 ytCOonܳoӳ]wpGzwgoGF峹CԱЬ http://www.s9y.org/index.php?node=46C');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', '}ҥ~ API');
@define('CALENDAR_EXTEVENT_DESC', 'pG}ҡA~iHb䤺HC㥦ƥCpGSϥγoǯS~AĳnϥΡC');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API \w[b s9y w˸̡A]|}MhHϥΪYCҥHzw XML-RPC ~pGnϥ XML-RPC APICҦ URL |]ܡAw˳oӥ~iHWϥΡC');
@define('PERM_READ', 'Read permission');
@define('PERM_READ', 'Ūv');
@define('PERM_WRITE', 'gJv');

@define('PERM_DENIED', 'vڵC');
@define('INSTALL_ACL', 'MJŪvO');
@define('INSTALL_ACL_DESC', 'pG}ҡAsչOv]wN|MΨnJ|CpGAOŪv|QϥΡAO|[ֱzxtסCpGzݭnhϥΪ̪ŪvAĳNoӳ]wC');
@define('PLUGIN_API_VALIDATE_ERROR', 'tm]w "%s" yk~Aݭn "%s" C');
@define('USERCONF_CHECK_PASSWORD', '±KX');
@define('USERCONF_CHECK_PASSWORD_DESC', 'pGzܤFKXAбNsKXJoC');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'zѤF~±KXҥHKXCz]w٥QxsC');
@define('ERROR_XSRF', 'zsǰeF~ HTTP-Referrer rCiO] browser/proxy ~]wάO Cross Site Request Forgery (XSRF) YCzʧ@LkC');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'o̥iHzwq۹ URL cyAq URL |Ū RSS-feeds зǡCziHγoܼ %id%, %realname%, %username%, %email% Ψ䥦rC');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed @̪ URL cy');
@define('INSTALL_PERMALINK_AUTHORSPATH', '@̭Ӹ|');
@define('AUTHORS', '@');
@define('AUTHORS_ALLOW_SELECT', '\Xܦh@̡H');
@define('AUTHORS_ALLOW_SELECT_DESC', 'pG\oӿﶵAXȥiHĿnŪ@̪峹C');
@define('AUTHOR_PLUGIN_DESC', 'ܧ@̦C');
@define('CATEGORY_PLUGIN_TEMPLATE', '} Smarty-TemplatesH');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'pG}ҳoӿﶵA~|Q Smarty-Templating \ӿXOCCz]iH "plugin_categories.tpl" Ҫɮרӧܥ~[Coӿﶵ|CܳtסApGzܡA̦noӿﶵC');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'ܨCO峹ơH');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'ܧ@̪峹ơH');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'pG}ҳoӳ]wA@̪峹Ʒ|ܦbWٮC');
@define('CUSTOM_ADMIN_INTERFACE', 'iΦۭq޲z');

@define('COMMENT_NOT_ADDED', 'zjT[J]g峹\jTAJF~TAΤqLU޲zC'); 
@define('INSTALL_TRACKREF', 'OӷH');
@define('INSTALL_TRACKREF_DESC', '}ҰOӷ|ܭӺޥΤFz峹CziHoӥ\pGӦhUsiC');
@define('CATEGORIES_HIDE_PARENT', 'ÿܪOH');
@define('CATEGORIES_HIDE_PARENT_DESC', 'zOܪCAw]O|ܥOW١CpGzoӥ\AOWٱN|ܡC');
@define('WARNING_NO_GROUPS_SELECTED', 'ĵiGzSܷ|sաCo|NznXsժ޲zA|sդ|QܡC');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'RSS Feed ܪ峹ƶqC');
@define('INSTAL_DB_UTF8', '}ҸƮwsXഫ');
@define('INSTAL_DB_UTF8_DESC', 'ϥ MySQL  "SET NAMES" dߨӳ]wsXCpG峹X{ýXiHNoӳ]w}C');
@define('ONTHEFLYSYNCH', '}ҧYɪCPB');
@define('ONTHEFLYSYNCH_DESC', 'pG}ҡASerendipity |ƮwMCؿɮסAMiƦPBC');
@define('USERCONF_CHECK_USERNAME_ERROR', 'bťաC');
@define('FURTHER_LINKS', 'hs');
@define('FURTHER_LINKS_S9Y', 'Serendipity ');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity ');
@define('FURTHER_LINKS_S9Y_BLOG', 'xx');
@define('FURTHER_LINKS_S9Y_FORUMS', '׾');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(jTwQ)');

@define('CURRENT_AUTHOR', 'ثe@');

@define('WORD_NEW', 's');
@define('SHOW_MEDIA_TOOLBAR', 'bܴC骺ܤuH');
@define('MEDIA_KEYWORDS', 'C骺r');
@define('MEDIA_KEYWORDS_DESC', 'Jw]CrA ";" Ӥ}CrC');
@define('MEDIA_EXIF', 'J EXIF/JPEG Ϥ');
@define('MEDIA_EXIF_DESC', 'pG}ҡAEXIF/JPEG ɸ̪ metadata |۰xsƮwC');
@define('MEDIA_PROP', 'C餺e');


@define('GO_ADD_PROPERTIES', 'Je');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'v');
@define('MEDIA_PROPERTY_COMMENT1', 'u');
@define('MEDIA_PROPERTY_COMMENT2', '');
@define('MEDIA_PROPERTY_TITLE', 'D');
@define('MEDIA_PROP_DESC', 'JCϥΪeA ";" Ӥ}C쪺W');
@define('MEDIA_PROP_MULTIDESC', '(ziHbW٫᭱[W ":MULTI" ӳ]w[jr)');

@define('STYLE_OPTIONS_NONE', 'oӧGSSOﶵCpGnbzG̥[WﶵAЬ www.s9y.org  Technical DocumentationAM "Configuration of Theme options"C');
@define('STYLE_OPTIONS', 'Gﶵ');

@define('PLUGIN_AVAILABLE_COUNT', '`@G %d ӥ~C');

@define('SYNDICATION_RFC2616', '}Ҩ̷Y檺 RFC2616 RSS-Feed');
@define('SYNDICATION_RFC2616_DESC', 'j RFC2616 ܥ GETs  Serendipity u|Ǧ^̫ק諸峹CpG]w "false" ܳXȷ|峹CLA@Ǻx`n鹳 Planet |X{_ǲ{HCpGX{_ǲ{HܥHϤF RFC2616 зǡCҥH]w "TRUE" ܧAq RFC зǡAOXȥi|Ū峹CӻAޫ˳LkUCTG<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', '');
@define('MEDIA_PROPERTY_RUN_LENGTH', '');
@define('FILENAME_REASSIGNED', '۰ʫwsɮתW١G %s');
@define('MEDIA_UPLOAD_SIZE', 'ɮפjpW');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Jɮת̤jȡCoӳ]w]iHqD PHP.ini ɮקܡG upload_max_filesize, post_max_size, max_input_time o̪]wLġCpGJܿqDC');
@define('MEDIA_UPLOAD_SIZEERROR', '~GzWǤj %s 줸ժɮסI');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Ϥ̤je');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'JWǪϤ̤jeסC');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Ϥ̤j');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'JWǪϤ̤jסC');
@define('MEDIA_UPLOAD_DIMERROR', '~GzWǤj %s x %s ϤI');

@define('MEDIA_TARGET', 'sؼ');
@define('MEDIA_TARGET_JS', 'uX (ϥ JavaScript)');
@define('MEDIA_ENTRY', 'j峹');
@define('MEDIA_TARGET_BLANK', 'uX (ϥ target=_blank)');

@define('MEDIA_DYN_RESIZE', '\ܹϤjpH');
@define('MEDIA_DYN_RESIZE_DESC', 'pG}ҡAC骺̷ܵ|ܨ̷ GET ܼƩҳ]wϤjpCϤ|xs֨O餺AҥH`ϥη|ΥDŶC');

@define('MEDIA_DIRECTORY_MOVED', 'ؿMɮפw\ʨ %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'ؿMɮ׵Lkʨ %sI');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'bD MySQL ƮwALkʤ峹sؿCzݭnۤvק峹}Cz٬OiHN¥ؿ^ШӪ}C');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', ' %s g峹xsؿC');
@define('PLUGIN_ACTIVE', '}');
@define('PLUGIN_INACTIVE', '');
@define('PREFERENCE_USE_JS', '}Ҷi JS ΪkH');
@define('PREFERENCE_USE_JS_DESC', 'pG}ҡAi JavaScript N|ѧnγ~AҦp~]woMʥ\C');

@define('PREFERENCE_USE_JS_WARNING', '(oӭϥΤFi JavaScriptCpGzJDAбNi JS Ϊks JavaScript C)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'd|');
@define('PERM_SET_CHILD', 'Nlؿ]ۦPv');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'TΥ~');
@define('PERMISSION_FORBIDDEN_HOOKS', 'TΨƥ');
@define('PERMISSION_FORBIDDEN_ENABLE', '}ҥ~ ACL |sաH');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'pG "~ ACL |s" O}ҪAAziHwYǸsըӰ~MƥC');
@define('DELETE_SELECTED_ENTRIES', 'Rܪ峹');
@define('PLUGIN_AUTHORS_MINCOUNT', 'ܦh X 峹@');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', '');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Noӳs]ҥiHzֳtiJxC');
@define('IMPORT_WP_PAGES', 'JɮשMRA󴶳qx峹H');
@define('USERCONF_CREATE', 'T|Tʧ@H');
@define('USERCONF_CREATE_DESC', 'pGĿA|NQTsηsWxʧ@CpGnJݡALQ\ʧ@unJnXMsۤv]wC');
@define('CATEGORY_HIDE_SUB', 'älO峹H');
@define('CATEGORY_HIDE_SUB_DESC', 'w]AOzsؿɡAlؿ峹]|ܡCpGĿ惡]wAu|sؿ峹C');
@define('PINGBACK_SENDING', 'ǰe^ %s...');
@define('PINGBACK_SENT', '^');
@define('PINGBACK_FAILED', '^ѡG %s');
@define('PINGBACK_NOT_FOUND', 'S^C');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'þvspGɶS峹 (ݭnp峹)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
